@@ -66,6 +66,8 @@ from chex._src.asserts import enable_asserts
 from chex._src.asserts import if_args_not_none
 from chex._src.dataclass import dataclass
 from chex._src.dataclass import mappable_dataclass
+from chex._src.dataclass import register_dataclass_type_with_jax_tree_util
+from chex._src.dimensions import Dimensions
 from chex._src.fake import fake_jit
 from chex._src.fake import fake_pmap
 from chex._src.fake import fake_pmap_and_jit
@@ -91,7 +93,7 @@ from chex._src.variants import TestCase
 from chex._src.variants import variants
 
 
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
 __all__ = (
     "all_variants",
@@ -152,6 +154,7 @@ __all__ = (
     "clear_trace_counter",
     "dataclass",
     "Device",
+    "Dimensions",
     "disable_asserts",
     "enable_asserts",
     "fake_jit",
@@ -163,6 +166,7 @@ __all__ = (
     "params_product",
     "PRNGKey",
     "PyTreeDef",
+    "register_dataclass_type_with_jax_tree_util",
     "restrict_backends",
     "Scalar",
     "set_n_cpu_devices",
