@@ -92,12 +92,13 @@ def _get_mappable_dataclasses(test_type):
         default_factory=lambda: dict(x='x', y='y'))
     k_default: str = 'default_str'
     k_non_init: int = dataclasses.field(default=1, init=False)
+    k_init_only: dataclasses.InitVar[int] = 10
 
     def some_method(self, *args):
       raise RuntimeError('NestedClassWithMap.some_method() was called.')
 
-    def __post_init__(self):
-      self.k_non_init = self.k_int * 10
+    def __post_init__(self, k_init_only):
+      self.k_non_init = self.k_int * k_init_only
 
   if test_type == 'chex':
     cls = chex_dataclass(Class, mappable_dataclass=True)
@@ -466,8 +467,10 @@ class DataclassesTest(parameterized.TestCase):
     @chex_dataclass(mappable_dataclass=is_mappable)
     class _Dcls:
       str_val: str
+      # pytype: disable=invalid-annotation  # enable-bare-annotations
       inner_dcls: _InnerDcls
       dct: Mapping[str, _InnerDcls]
+      # pytype: enable=invalid-annotation  # enable-bare-annotations
 
     dcls = _Dcls(
         str_val='test',
@@ -482,13 +485,13 @@ class DataclassesTest(parameterized.TestCase):
       self.assertNotIsInstance(value, int)
       return isinstance(value, (_InnerDcls, str))
 
-    leaves = jax.tree_flatten(dcls, is_leaf=_is_leaf)[0]
+    leaves = jax.tree_util.tree_flatten(dcls, is_leaf=_is_leaf)[0]
     self.assertCountEqual(
         (dcls.str_val, dcls.inner_dcls, dcls.dct['md1'], dcls.dct['md2']),
         leaves)
 
     asserts.assert_tree_all_equal_structs(
-        jax.tree_map(lambda x: x, dcls, is_leaf=_is_leaf), dcls)
+        jax.tree_util.tree_map(lambda x: x, dcls, is_leaf=_is_leaf), dcls)
 
   @parameterized.named_parameters(
       ('mappable', True),
@@ -505,7 +508,7 @@ class DataclassesTest(parameterized.TestCase):
 
     @chex_dataclass(mappable_dataclass=mappable)
     class GenericDataclass(Generic[T]):
-      a: T
+      a: T  # pytype: disable=invalid-annotation  # enable-bare-annotations
 
     obj = GenericDataclass(a=np.array([1.0, 1.0]))
     asserts.assert_tree_all_close(obj.a, 1.0)
